<!-- <p align="center">
    <img src="https://github.com/suzgunmirac/string2string/blob/main/fables/string2string-logo.png" class="center"/>
</p> -->

<p align="center">
    <img src="https://github.com/suzgunmirac/string2string/blob/main/fables/string2string-overview.png" class="center" />
</p>

# string2string


[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/string2string)](https://badge.fury.io/py/string2string)
[![PyPI version](https://badge.fury.io/py/string2string.svg)](https://badge.fury.io/py/string2string)
[![Downloads](https://pepy.tech/badge/string2string)](https://pepy.tech/project/string2string)
[![Build Status](https://github.com/suzgunmirac/string2string/workflows/tests/badge.svg)](https://github.com/suzgunmirac/string2string)
[![license](https://img.shields.io/github/license/suzgunmirac/string2string.svg)](https://github.com/suzgunmirac/string2string/blob/main/LICENSE.txt)

![Tests](https://github.com/suzgunmirac/string2string/workflows/Tests/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/suzgunmirac/string2string/badge.svg?branch=main)](https://coveralls.io/github/suzgunmirac/string2string?branch=main)

## Getting Started

To use the `string2string` library, it is necessary to install it using `pip`. If you have not installed the library before, you can follow the instructions below:

1. Open a terminal or command prompt on your computer.

2. Create a virtual environment to install the library. This is an optional step, but it is recommended to keep your environment clean and avoid conflicts with other installed packages. You can create a virtual environment using `virtualenv` or `conda`, depending on your preferences and setup.

3. Activate the virtual environment if you created one.

4. Install the string2string library by running the following command in your terminal:

```python
pip install string2string
```

Once the installation is complete, you can import the library and start using its functionalities.

*Remark*: We recommend using Python 3.7+.

## Tutorials

## Citation

```
@misc{suzgun2023_string2string,
    title={tring2string: A Modern Python Library for String-to-String Algorithms},
    author={Suzgun, Mirac and Shieber, Stuart M. and Jurafsky, Dan},
    year={2023},
    [TBD],
}
```
